# AXValueConstants.h Documentation

## Overview
This header defines values used for certain attributes, such as sort direction and orientation.

## Constants

| Constant Name | Description |
| :--- | :--- |
| `kAXAscendingSortDirectionValue` | Contents are sorted in ascending order. |
| `kAXDescendingSortDirectionValue` | Contents are sorted in descending order. |
| `kAXHorizontalOrientationValue` | Object is oriented horizontally. |
| `kAXUnknownOrientationValue` | Orientation is unknown. |
| `kAXUnknownSortDirectionValue` | Sort order is unknown. |
| `kAXVerticalOrientationValue` | Object is oriented vertically. |
